pycbc_submit_dax --no-grid --no-create-proxy \
--local-dir ./ \
--no-query-db \
